| Title: | A Set of Color Palettes Inspired by OK Go Music Videos for 'ggplot2' in R |
|---|---|
| Description: | A collection of aesthetically appealing color palettes for effective data visualization with 'ggplot2'. Palettes support both discrete and continuous data. |
| Authors: | Nelson de O. Quesado Filho [aut, cre], Ana Flávia Teles Silveira [aut] |
| Maintainer: | Nelson de O. Quesado Filho <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.2 |
| Built: | 2026-07-02 21:39:00 UTC |
| Source: | https://github.com/cran/okcolors |
Returns n colors from a palette included in okcolors.
okcolors(palette = "obsession", n = 5, direction = 1)okcolors(palette = "obsession", n = 5, direction = 1)
palette |
Character. Name of the palette to use. See |
n |
Integer. Number of colors to return. Default is |
direction |
Integer. Use |
A character vector of hex color codes of length n.
okcolors("stone", 3) okcolors("obsession", 7, direction = -1)okcolors("stone", 3) okcolors("obsession", 7, direction = -1)
Applies a custom continuous or discrete color scale to ggplot2 plots using a selected okcolors palette.
scale_color_okcolors( palette = "obsession", discrete = FALSE, direction = 1, ... )scale_color_okcolors( palette = "obsession", discrete = FALSE, direction = 1, ... )
palette |
Character. Name of the palette to use. See |
discrete |
Logical. Whether to use a discrete scale ( |
direction |
Integer. Use |
... |
Additional arguments passed to |
A Scale object that can be added to a ggplot2 plot.
Applies a custom continuous or discrete fill scale to ggplot2 plots using a selected okcolors palette.
scale_fill_okcolors( palette = "obsession", discrete = FALSE, direction = 1, ... )scale_fill_okcolors( palette = "obsession", discrete = FALSE, direction = 1, ... )
palette |
Character. Name of the palette to use. See |
discrete |
Logical. Whether to use a discrete scale ( |
direction |
Integer. Use |
... |
Additional arguments passed to |
A Scale object that can be added to a ggplot2 plot.
Returns a character vector of all valid palette names supported by the okcolors package.
valid_palettes()valid_palettes()
A character vector with the names of available palettes.
valid_palettes()valid_palettes()